@@ -17,7 +17,7 @@ class AbbreviationDetector(six.with_metaclass(ABCMeta)):
         self.tokenizer = AutoTokenizer.from_pretrained(model_name, model_max_length=512)
         self.device = device if device else -1
         self.model = pipeline('token-classification', model_name, tokenizer=self.tokenizer,
-                              use_auth_token=True, aggregation_strategy='simple', device=self.device)
+                              aggregation_strategy='simple', device=self.device)
 
     def detect_spans(self, tokens):
         """
