@@ -18,7 +18,7 @@ class BertCemTagger(BertTagger):
         cner_tagger = pipeline("token-classification", model="batterydata/bde-cner-batteryonlybert-uncased-base",
                                tokenizer=AutoTokenizer.from_pretrained("batterydata/bde-cner-batteryonlybert-uncased-base",
                                                                        model_max_length=512),
-                               aggregation_strategy="simple", use_auth_token=True, device=self.device)
+                               aggregation_strategy="simple", device=self.device)
         result = cner_tagger([token[0] for token in tuples])
         labels = ['O' if token == [] else 'MAT' for token in result]
         tagged_sent = list(zip(tuples, labels))
